@@ -1,9 +1,11 @@
+#[cfg(feature = "treasury")]
 pub mod treasury;
 
-use {
-    std::{error::Error, future::Future},
-    uuid::Uuid,
-};
+use std::error::Error;
+
+use futures::future::BoxFuture;
+
+use crate::AssetId;
 
 /// Asset data loaded from [`Source`].
 pub struct AssetData {
@@ -21,14 +23,20 @@ pub trait Source: Send + Sync + 'static {
     /// Error that may occur during asset loading.
     type Error: Error + Send + Sync;
 
-    /// Future that resolves int loaded asset data, error or None.
-    type Fut: Future<Output = Result<Option<AssetData>, Self::Error>> + Send;
+    /// Searches for the asset by given path.
+    /// Returns `Ok(Some(asset_data))` if asset is found and loaded successfully.
+    /// Returns `Ok(None)` if asset is not found.
+    fn find(&self, path: &str, asset: &str) -> BoxFuture<Option<AssetId>>;
 
     /// Load asset data from this source.
     /// Returns `Ok(Some(asset_data))` if asset is loaded successfully.
     /// Returns `Ok(None)` if asset is not found, allowing checking other sources.
-    fn load(&self, uuid: &Uuid) -> Self::Fut;
+    fn load(&self, id: AssetId) -> BoxFuture<Result<Option<AssetData>, Self::Error>>;
 
     /// Update asset data if newer is available.
-    fn update(&self, uuid: &Uuid, version: u64) -> Self::Fut;
+    fn update(
+        &self,
+        id: AssetId,
+        version: u64,
+    ) -> BoxFuture<Result<Option<AssetData>, Self::Error>>;
 }
